pub struct ToStringOptions {
pub pretty: bool,
pub trailing_semicolon: bool,
pub single_statement_on_new_line: bool,
pub include_type_annotations: bool,
pub include_decorators: bool,
pub comments: Comments,
pub indent_with: String,
pub expect_jsx: bool,
pub expect_markers: bool,
pub max_line_length: u8,
}Expand description
Settings for serializing ASTNodes
Fields
pretty: boolDoes not include whitespace minification
trailing_semicolon: boolBlocks have trailing semicolons. Has no effect if pretty == false
single_statement_on_new_line: boolSingle statements get put on the same line as their parent statement
include_type_annotations: boolInclude type annotations (and additional TypeScript) syntax
include_decorators: boolTODO unsure about this
comments: Commentsindent_with: Stringexpect_jsx: boolIf false, panics if sees JSX
expect_markers: boolFor partial AST, marker nodes may exist. This allows pretty printing on invalid source
but should be false for builds
if false and a marker node is found, printing will panic
max_line_length: u8has no effect under !pretty
Implementations
Sourceimpl ToStringOptions
impl ToStringOptions
pub fn minified() -> ToStringOptions
Sourcepub fn typescript() -> ToStringOptions
pub fn typescript() -> ToStringOptions
With TypeScript type syntax